@@ -11,7 +11,7 @@
 submission      587/tcp
 submission      587/udp
 EOF2
-      killall -HUP inetd
+      /bin/killall -HUP inetd
   fi
 )
     
@@ -34,3 +34,5 @@ EOF2
 ( cd usr/bin ; ln -sf ../../usr/sbin/sendmail newaliases )
 ( cd usr/bin ; rm -rf mailq )
 ( cd usr/bin ; ln -sf ../../usr/sbin/sendmail mailq )
+( cd usr/lib ; rm -rf sendmail )
+( cd usr/lib ; ln -sf ../../../usr/sbin/sendmail sendmail )
